cert

package
v0.0.0-...-698bbad Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InjectCertAnnotation

func InjectCertAnnotation(annotation map[string]string, namespace string) map[string]string

func WaitForCertificateReady

func WaitForCertificateReady(ctx context.Context, dynamicClient dynamic.Interface, namespace, certificateName string, timeout time.Duration) error

WaitForCertificateReady waits for a cert-manager Certificate to be ready by checking that it's issued and the Secret exists with valid certificate data

Types

This section is empty.

Jump to