Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InjectCertAnnotation ¶
func WaitForCertificateReady ¶
func WaitForCertificateReady(ctx context.Context, dynamicClient dynamic.Interface, namespace, certificateName string, timeout time.Duration) error
WaitForCertificateReady waits for a cert-manager Certificate to be ready by checking that it's issued and the Secret exists with valid certificate data
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.